"""
This is the "sailfish.py" module, and it provides the following functions:

1. print_lol() prints lists (that may or may not include nested lists) to screen
   (by defaut) or another file, with each item on its own line. Note: nested lists 
   can be indented, if necessary.

2. open_file_as_lines() returns a list, each item of which is one line (by default,
   line feed is removed, but the line is not stripped) of the provided file (in turn).

"""

import sys

def print_lol(the_list, indent=False, level=0, file=sys.stdout):
	'''
	This function takes a positional argument called "the_list", which is
	any Python list (of, possibly, nested lists). Each data item in the 
	provided list is (recursively) printed to the screen (by default) or another
	file on its own line. Note: nested lists can be indented, if necessary.

	A second argument called "indent" is used to switch on/off the indentation
	feature.

	A third argument called "level" is used to insert tab-stops when a 
	nested list is encounted. Use the value of "level" to control how many
	tab-stops are used.
	
	A fourth argument called "file" is used to specify the place to write the data to.
	'''
	for each_item in the_list:
		if isinstance(each_item, list):
			print_lol(each_item, indent, level+1, file)
		else:
			'''
			# Use this "for" loop or the following "if" statement
			for num_tab_stops in range(level):
				print("\t", end='', file=file)
			'''
			if indent==True:
				print("\t"*level, end='', file=file)
			print(each_item, file=file)


def open_file_as_lines(file, remove_linefeed=True, strip=False):
	'''
	This function takes a positional argument called "file", which is the file
    to be opened. The function returns a list, each item of which is one line (by default,
	line feed is removed, but the line is not stripped) of the provided file (in turn). 
	'''
	
	lines = []
	
	'''	
	try:
		data_file = open(file)
		
		for each_line in data_file:
			if remove_linefeed == True:
				(each_line, extra) = each_line.split("\n", 1)
			lines.append(each_line)
		
		return lines
	
	except IOError as err:
		print("File Error: " + str(err))
		return None
	finally:
		if "data_file" in locals():
			data_file.close()
	'''

	'''
	The above try/except/finally can be simplified by using the "with" statement.
	'''
	try:
		with open(file) as data_file:
			for each_line in data_file:
				if remove_linefeed == True:
					(each_line, extra) = each_line.split("\n", 1)
				if strip == True:
					each_line.strip()
				lines.append(each_line)
		
		return lines
	except IOError as err:
		print("File Error: " + str(err))
		return None
			
